@@ -10,6 +10,7 @@ import datetime
 import decimal
 import sys
 import logging
+import re
 
 logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 
@@ -133,36 +134,33 @@ class Context:
     def fill_parameters(self, expr, object_id, field, pattern=None):
         if expr.find('${') == -1:
             return expr
-        ret = ''
-        prev_c = None
-        parameter_index = -1
-        for i, c in enumerate(expr):
-            if parameter_index == -1:
-                if prev_c == '$' and c == '{':
-                    parameter_index = i + 1
-                    ret = ret[:-1]
-                else:
-                    ret += c
-            else:
-                if c == '}':
-                    parameter_name = expr[parameter_index:i]
-                    param_ref = self.get_parameter(parameter_name)
-                    if param_ref is None:
-                        raise ReportBroError(
-                            Error('errorMsgInvalidExpressionNameNotDefined',
-                                  object_id=object_id, field=field, info=parameter_name))
+
+        ret = {}
+        str_list = expr.split(" ")
+        parameters = list(filter(lambda item: item.find('}') != -1, str_list))
+
+        for item in parameters:
+            parameter_name = re.sub('[${.*}]', '', item)
+
+            if parameter_name != '':
+                param_ref = self.get_parameter(parameter_name)
+
+                if param_ref is not None:
                     value, value_exists = Context.get_parameter_data(param_ref)
 
                     if not value_exists:
                         raise ReportBroError(
                             Error('errorMsgMissingParameterData',
-                                  object_id=object_id, field=field, info=parameter_name))
+                                object_id=object_id, field=field, info=parameter_name))
 
                     if value is not None:
-                        ret += self.get_formatted_value(value, param_ref.parameter, object_id, pattern=pattern)
-                    parameter_index = -1
-            prev_c = c
-        return ret
+                        formated_value = self.get_formatted_value(value, param_ref.parameter, object_id, pattern=pattern)
+                        ret.update({item: formated_value})
+
+        for key in ret.keys():
+            expr = expr.replace(key, ret[key])
+
+        return expr
 
     def evaluate_expression(self, expr, object_id, field):
         if expr:
