@@ -93,6 +93,6 @@ class FilterParams(Enum):
     fixed = "FIXED"
     lower_case = "LOWERCASE"
     upper_case = "UPPERCASE"
-    time_current = "TIMECURRENT"
+    time_current = "NOW"
     capitalize = "CAPITALIZE"
     capitalize_all = "CAPITALIZEALL"
